pub fn has_concurrent_fields(layout: &StructLayout) -> boolExpand description
Returns true if any field has a Concurrent access pattern.
pub fn has_concurrent_fields(layout: &StructLayout) -> boolReturns true if any field has a Concurrent access pattern.