pub fn parse_source(
path: &Path,
arch: &'static ArchConfig,
) -> Result<ParseOutput>Expand description
Parse a source file and return layouts plus any skipped types.
pub fn parse_source(
path: &Path,
arch: &'static ArchConfig,
) -> Result<ParseOutput>Parse a source file and return layouts plus any skipped types.