Module suppress
padlock_
source
0.10.0
Module suppress
Module Items
Functions
In padlock_
source::
frontends
padlock_source
::
frontends
Module
suppress
Functions

extract_
suppressed_
kinds
Parse
padlock: ignore[Kind1, Kind2]
from a single comment line. The input may be a whole line (including leading
//
or
/*
) or just the content of a doc attribute string (Rust
#[doc = "..."]
).
suppressed_
from_
preceding_
source
Scan the source text
before
node_start_byte
for suppression directives.
suppressed_
from_
source_
line
Variant for parsers (like the Rust
syn
frontend) that know the 1-indexed line number of the struct rather than its byte offset.